@@ -12,8 +12,8 @@ from .win_button import NWinButton
 from .simple_color_fade import NSimpleColorFade
 from .win_animated_button import NWinAnimatedButton
 from .checkbox import NCheckBox
-from .checkbox_animated import NCheckBoxAnimated
+from .checkbox_animated import NAnimatedCheckBox
 from .simple_line_edit import NSimpleLineEdit
 
 
-__version__ = '0.0.1'
+__version__ = '0.0.2'
